summaryrefslogtreecommitdiff
path: root/Source/WebCore/inspector/front-end/UIUtils.js
diff options
context:
space:
mode:
Diffstat (limited to 'Source/WebCore/inspector/front-end/UIUtils.js')
-rw-r--r--Source/WebCore/inspector/front-end/UIUtils.js4
1 files changed, 2 insertions, 2 deletions
diff --git a/Source/WebCore/inspector/front-end/UIUtils.js b/Source/WebCore/inspector/front-end/UIUtils.js
index ce5b3dbdf..7f93f0d22 100644
--- a/Source/WebCore/inspector/front-end/UIUtils.js
+++ b/Source/WebCore/inspector/front-end/UIUtils.js
@@ -50,8 +50,8 @@ WebInspector.installDragHandle = function(element, elementDragStart, elementDrag
*/
WebInspector._elementDragStart = function(elementDragStart, elementDrag, elementDragEnd, cursor, event)
{
- // Only drag upon left button. Right will likely cause a context menu.
- if (event.button)
+ // Only drag upon left button. Right will likely cause a context menu. So will ctrl-click on mac.
+ if (event.button || (WebInspector.isMac() && event.ctrlKey))
return;
if (WebInspector._elementDraggingEventListener)